==> vue-year-table-2.21.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/year-table/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import '@opentinyvue/vue-theme/year-table/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["pick", "changerange"],
  props: [].concat(props, ["disabledDate", "value", "defaultValue", "date", "selectionMode", "startYear", "maxDate", "minDate", "rangeState"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("table", {
    staticClass: "tiny-year-table",
    on: {
      "mousemove": _vm.handleMouseMove,
      "click": _vm.handleYearTableClick
    }
  }, [_c("tbody", _vm._l(_vm.state.rows, function(row, trKey) {
    return _c("tr", {
      key: trKey
    }, _vm._l(row, function(cell, tdKey) {
      return _c("td", {
        key: tdKey,
        staticClass: "available",
        class: [{
          "disabled": _vm.getIsDisabled(cell.text),
          "current": _vm.getIsCurrent(cell.text),
          "default": _vm.getIsDefault(cell.text),
          "today": _vm.state.currentYear === cell.text,
          "in-range": cell.inRange,
          "start-date": cell.start,
          "end-date": cell.end
        }]
      }, [_c("div", [_c("a", {
        staticClass: "cell",
        attrs: {
          "aria-disabled": _vm.getIsDisabled(cell.text) ? true : void 0
        }
      }, [_vm._v(_vm._s(cell.text))])])]);
    }), 0);
  }), 0)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };

==> vue-year-table-2.22.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/year-table/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import '@opentinyvue/vue-theme/year-table/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["pick", "changerange"],
  props: [].concat(props, ["disabledDate", "value", "defaultValue", "date", "selectionMode", "startYear", "maxDate", "minDate", "rangeState", "readonly"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("table", {
    staticClass: "tiny-year-table",
    on: {
      "mousemove": _vm.handleMouseMove,
      "click": _vm.handleYearTableClick
    }
  }, [_c("tbody", _vm._l(_vm.state.rows, function(row, trKey) {
    return _c("tr", {
      key: trKey
    }, _vm._l(row, function(cell, tdKey) {
      return _c("td", {
        key: tdKey,
        staticClass: "available",
        class: [{
          "disabled": _vm.getIsDisabled(cell.text),
          "current": _vm.getIsCurrent(cell.text),
          "default": _vm.getIsDefault(cell.text),
          "today": _vm.state.currentYear === cell.text,
          "in-range": cell.inRange,
          "start-date": cell.start,
          "end-date": cell.end
        }]
      }, [_c("div", [_c("a", {
        staticClass: "cell",
        attrs: {
          "aria-disabled": _vm.getIsDisabled(cell.text) ? true : void 0
        }
      }, [_vm._v(_vm._s(cell.text))])])]);
    }), 0);
  }), 0)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
